@@ -29,7 +29,7 @@
               I n c l u d e s
 ----------------------------------------------------------------------*/
 #include "dawg.h"
-#include "util.h"
+#include "cutil.h"
 
 /*----------------------------------------------------------------------
               T y p e s
